@@ -11,11 +11,15 @@ enum {
   SPVM_API_C_STACK_LENGTH = 512,
 };
 
+enum {
+  SPVM_API_C_CALL_STACK_MEMORY_BLOCK_SIZE = 2048,
+};
+
 enum {
   SPVM_API_C_STACK_INDEX_TMP_BUFFER = 384, // 384 to 511
   SPVM_API_C_STACK_INDEX_EXCEPTION = 383,
   SPVM_API_C_STACK_INDEX_MORTAL_STACK = 382,
-  SPVM_API_C_STACK_INDEX_MORTAL_STACK_TOP = 381,
+  SPVM_API_C_STACK_INDEX_MORTAL_STACK_LENGTH = 381,
   SPVM_API_C_STACK_INDEX_MORTAL_STACK_CAPACITY = 380,
   SPVM_API_C_STACK_INDEX_ARGS_WIDTH = 379,
   SPVM_API_C_STACK_INDEX_CALL_DEPTH = 378,
@@ -23,6 +27,13 @@ enum {
   SPVM_API_C_STACK_INDEX_SEED = 376,
   SPVM_API_C_STACK_INDEX_SEED_INITIALIZED = 375,
   SPVM_API_C_STACK_INDEX_ALL_METHOD_CALL_PERMITTED = 374,
+  SPVM_API_C_STACK_INDEX_CALL_STACK_FRAME_INFOS = 373,
+  SPVM_API_C_STACK_INDEX_CALL_STACK_FRAME_INFOS_LENGTH = 372,
+  SPVM_API_C_STACK_INDEX_CALL_STACK_FRAME_INFOS_CAPACITY = 371,
+  SPVM_API_C_STACK_INDEX_CALL_STACK_OFFSET = 370,
+  SPVM_API_C_STACK_INDEX_CALL_STACK_MEMORY_BLOCKS = 369,
+  SPVM_API_C_STACK_INDEX_CALL_STACK_MEMORY_BLOCKS_CAPACITY = 368,
+  SPVM_API_C_STACK_INDEX_MEMORY_BLOCKS_FOR_CALL_STACK = 367,
 };
 
 enum {
@@ -40,7 +51,6 @@ void SPVM_API_free_env(SPVM_ENV* env);
 SPVM_VALUE* SPVM_API_new_stack(SPVM_ENV* env);
 SPVM_VALUE* SPVM_API_new_stack_with_all_method_call_permitted(SPVM_ENV* env);
 void SPVM_API_free_stack(SPVM_ENV* env, SPVM_VALUE* stack);
-
 int32_t SPVM_API_args_width(SPVM_ENV* env, SPVM_VALUE* stack);
 
 // Initialize/Cleanup
@@ -429,5 +439,12 @@ int32_t SPVM_API_is_mulnum_type(SPVM_RUNTIME* runtime, SPVM_RUNTIME_BASIC_TYPE*
   The end of type native APIs
 */
 
+int32_t SPVM_API_get_call_stack_frame_size(SPVM_RUNTIME_METHOD* method);
+int32_t SPVM_API_push_call_stack_frame(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_RUNTIME_CALL_STACK_FRAME_INFO* call_stack_frame_info);
+void SPVM_API_pop_call_stack_frame(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_RUNTIME_CALL_STACK_FRAME_INFO* call_stack_frame_info);
+int32_t SPVM_API_set_call_stack_frame_info(SPVM_ENV* env, SPVM_VALUE* stack, SPVM_RUNTIME_CALL_STACK_FRAME_INFO* call_stack_frame_info, char* call_stack_frame);
+void* SPVM_API_new_memory_block_for_call_stack(SPVM_ENV* env, SPVM_VALUE* stack, int32_t size);
+
+void SPVM_API_free_memory_block_for_call_stack(SPVM_ENV* env, SPVM_VALUE* stack, void* block);
 
 #endif
